/*****************************************************************************
 *
 * File:        app.cmd
 *
 * Author:      Sven Mulka
 *
 * Company:     Ingenieurbro Mulka, Software & Data Communication
 *              Copyright (c) 2018, by IB-Mulka
 *              http://www.ib-mulka.de
 *
 * Content:     Application specific linker command file,
 *              e.g. add your own section here.
 *
 *              For more details look here:
 *              http://rtsc.eclipse.org/docs-tip/Memory_Management
 *
 * Changes:
 * 20.06.18 SM  Initial Version
 *
 *****************************************************************************/
/*
 * $Log:   $
 */

/*****************************************************************************
 * ROM model uses an additional copying during runtime
 */
--rom_model

/***
 * Use compression to save space on ROM
 */
--cinit_compression=lzss
--copy_compression=lzss

/***
 * Set stack and heap size
 */
-stack=0x10000
-heap  0x20000

--args 0x0

/*****************************************************************************
 * The Memory definition
 */
MEMORY
{
	MSMCSRAM (RWX)			: org = 0x0c020000, len = 0x000e0000
	L2SRAM (RWX)			: org = 0x00800000, len = 0x00080000
	OMP_MSMC_NC_PHY (RW)	: org = 0x0c000000, len = 0x00020000
	OMP_MSMC_NC_VIRT (RWX)	: org = 0xa0000000, len = 0x00020000
	DDR3 (RWX)				: org = 0x80000000, len = 0x20000000
}

/*****************************************************************************
 * Add our own sections here.
 * All other sections defined by SYSBIOS and in app.cfg.
 */
SECTIONS
{
	/***
	 *  The .far & .fardata sections of the RTSC genenerated 'C' file (appname)
	 *  and the RTS libraries (*rts*.lib) consist of global variables that must
	 *  be local to each core.  These sections are therefore placed in
	 *  memory local to each core.
	 */
	.localfar :
	{
		"*rts*.lib" (.far)
		"*rts*.lib" (.fardata)
//		"app_pe66.oe66" (.far)
//		"app_pe66.oe66" (.fardata)

	} > L2SRAM

	/***
	 * Place the .TI.tls section to avoid a linker defect related to
	 * default placement. This section is not used because the runtime
	 * dynamically allocates TLS.
	 */
	.TI.tls			> DDR3, palign = 128

	/* tls_init must be placed in a region that has not been mapped via MPAX
	 * since it is initialized by the loader
	 */
	.TI.tls_init	> DDR3, palign = 128

	.tdata			> DDR3, palign = 128

	/***
	 * Default placement based on linker.cmd
	 */
	GROUP: load > DDR3 align = 0x80
	{
		.bss:
		.neardata:
		.rodata:
	}

	/***
	 * Here may be a bug during the program load.
	 * The first 128 bytes of DDR3 will be filled with zeros.
	 * We are placing the ramdisk and uPP sections at the front
	 * of DDR3 memory.
	 */
	GROUP load = DDR3
	{
		/* create a hole of 512 bytes */
		guard_ddr3	: fill = 0xAFFEAFFE { . += 0x200; }

		.text:_c_int00		: palign = 0x400
		.text				: palign = 128
		.far				: palign = 128
		.binit				: palign = 128
		.pinit				: palign = 128
		.init_array			: palign = 128
		.const				: palign = 128
		.data				: palign = 128
		.switch				: palign = 128
		.sysmem				: palign = 128
		.ti.handler_table	: palign = 128
		.c6xabi.exidx		: palign = 128
		.c6xabi.extab		: palign = 128
		.binit				: palign = 128
		.tbss				: palign = 128
		.vecs				: palign = 128
	}

	.cinit		: palign = 128, load = DDR3

	.fardata	: palign = 128, load = L2SRAM
	.stack		: palign = 128, load = L2SRAM

	.args		: load = L2SRAM align = 0x80, fill = 0 {_argsize = 0x0; }
	.cio		: load = L2SRAM align = 0x80

	/***
	 * Data sections in MSMCSRAM
	 * will be loaded at runtime from .cinit section
	 *
	 * Used by test.fill
	 */
//	.omp_data : palign = 128, load = OMP_MSMC_NC_PHY, run = OMP_MSMC_NC_VIRT

	/***
	 * Try to compress some test data used by test.binit command.
	 * It will be decompress at runtime of application.
	 */
	test_data.binit : palign = 128, run = MSMCSRAM, load = DDR3, table(test_data_binit_table)
//	test_data.binit : palign = 128, run = MSMCSRAM, load = DDR3, table(BINIT)
	test_data.cinit : palign = 128, run = MSMCSRAM

	/***
	 * Try to compress code.
	 * It will be decompress at runtime of application.
	 */
	test_code.binit : palign = 128, run = L2SRAM, load = DDR3, table(test_code_binit_table)

	/***
	 * Holds the overlay tables, generated for BINIT and others
	 */
	.ovly : palign = 128, load = DDR3

}

/*****************************************************************************/
