/*****************************************************************************
 *
 * File:        test_data_binit.cpp
 *
 * Author:      Sven Mulka
 *
 * Company:     Ingenieurbro Mulka, Software & Data Communication
 *              Copyright (c) 2018, by IB-Mulka
 *              http://www.ib-mulka.de
 *
 * Content:     Test Application to trigger RBL issue it section length
 *              is not multiple of 4 bytes.
 *
 * Changes:
 * 17.07.18 SM  Initial Version
 *
 *****************************************************************************/
/*
 * $Log:   $
 */
#include <cpy_tbl.h>
#include <iostream>
#include <iomanip>

using namespace std;

/*****************************************************************************/

#define USE_PRIVATE_BINIT_TABLE		1

extern _DATA_ACCESS COPY_TABLE const test_data_binit_table[];

/***
 * Both section are LZSS compressed. The content should be:
 *
 * 00	FD	2A	00	0F	25	0A	48	65	6C	6C	6F	FF	20	77	6F
 * 72	6C	64	2C	0A	DF	74	68	69	73	20	00	20	61	20	FF
 * 73	69	6D	70	6C	65	20	74	FF	65	73	74	20	73	74	72
 * 69	FF	6E	67	20	74	6F	20	63	68	FF	65	63	6B	20	74
 * 68	61	74	FF	20	42	49	4E	49	54	20	6C	D7	6F	61	64
 * 01	B0	0A	03	60	74	68	FF	65	20	73	61	6D	65	20	61
 * B7	73	20	43	01	C9	2E	0A	09	CF	27	00	00	00	0F	17
 * FF	F0
 */
#pragma DATA_SECTION("test_data.binit")
char g_test_data_binit[0x00000100] =
"********************************************************\n"
"Hello world,\n"
"this is a simple test string to check that BINIT loading\n"
"is the same as CINIT loading.\n"
"********************************************************\n"
;

#pragma DATA_SECTION("test_data.cinit")
char g_test_data_cinit[0x00000100] =
"********************************************************\n"
"Hello world,\n"
"this is a simple test string to check that BINIT loading\n"
"is the same as CINIT loading.\n"
"********************************************************\n"
;

/***
 * Run BINIT test for data.
 */
bool test_data_binit()
{
	using namespace std;

	cout << endl
		 << "********************************************************" << endl
		 << "Running test.data.binit ..." << endl
		 << endl
		 ;

#if USE_PRIVATE_BINIT_TABLE
	/***
	 * Clear binit data
	 */
	memset((void*)g_test_data_binit, 0, sizeof(g_test_data_binit));

	/***
	 * Load binit data from compressed section
	 */
	copy_in((COPY_TABLE *)test_data_binit_table);
#endif
	/***
	 * Check the content.
	 */
	if (!memcmp(g_test_data_binit, g_test_data_cinit, sizeof(g_test_data_cinit)))
	{
		cout << "g_test_data_binit == g_test_data_cinit"  << endl
			 << "... done"  << endl
			 << "********************************************************" << endl
			 << endl
			 ;
		return true;
	}
	else
	{
		cout << "g_test_data_binit != g_test_data_cinit" << endl
			 << "********************************************************" << endl
			 << endl
			 ;
		return false;
	}
}

/*****************************************************************************/
